<?php
/***************************************************************
*  Copyright notice
*
*  (c) 2011  Andreas Kessel <typo3-dev@formatsoft.de>
*  All rights reserved
*
*  This script is part of the TYPO3 project. The TYPO3 project is
*  free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  The GNU General Public License can be found at
*  http://www.gnu.org/copyleft/gpl.html.
*
*  This script is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  This copyright notice MUST APPEAR in all copies of the script!
***************************************************************/

use TYPO3\CMS\Core\Utility\GeneralUtility;

/**
* Class tx_formatt3tools_dbcheck
*
* @author	Andreas Kessel <typo3-dev@formatsoft.de>
* @package  TYPO3
* @subpackage	tx_formatt3tools
*/
class tx_formatt3tools_dbcheck extends \TYPO3\CMS\Scheduler\Task\AbstractTask {

	/**
	 * Email address to send email notification to in case we find problems with
	 * the system.
	 *
	 * @var	string
	 */
	protected $notificationEmail = NULL;
	protected $maxDbSize = 1;


	/**
	 * Function executed from scheduler.
	 * Send the newsletter
	 * 
	 * @return	void
	 */
	function execute() {
		$GLOBALS['LANG']->includeLLFile('EXT:format_t3tools/tasks/locallang.xml'); 
		
        // Check if cronjob is already running:
		$lockfile = PATH_site . 'typo3temp/tx_format_t3tools_cron.lock';
		if (@file_exists($lockfile)) {
				// If the lock is not older than 1 day, skip index creation:
			if (filemtime($lockfile) > (time() - (60*60*24))) {
				$GLOBALS['BE_USER']->writelog(
					4,
					0,
					1,
					'tx_format_t3tools',
					'TYPO3 format_t3tools Cron: Aborting, another process is already running!',
					array()
				);
				return false;
			} else {
				$GLOBALS['BE_USER']->writelog(
					4,
					0,
					0,
					'tx_format_t3tools',
					'TYPO3 format_t3tools Cron: A .lock file was found but it is older than 1 day! Processing mails ...',
					array()
				);
			}
		}

		touch ($lockfile);

        $gesamt = 0;
        $query = "Show Table Status";
        $result = $GLOBALS['TYPO3_DB']->sql_query($query);
        while ($row = $GLOBALS['TYPO3_DB']->sql_fetch_assoc($result)) {
            $summe = $row["Index_length"] + $row["Data_length"];
            //$mailSubject = "Tabelle " . $row["Name"] . ": $summe byte";
            $gesamt += $summe;
        }

        $gesamtMByte = round($gesamt / (1024 * 1024),1);

        if($gesamtMByte > $this->maxDbSize){
          $this->sendNotificationEmail($gesamtMByte.' MByte');
        } 

		unlink ($lockfile);
		return true;
	} // end of 'function execute() {..}'



	/**
	 * Gets the notification email address.
	 *
	 * @return	string	Notification email address.
	 */
	public function getNotificationEmail() {
		return $this->notificationEmail;
	}
	
	
	/**
	 * Gets the maxDbSize.
	 *
	 * @return	int	maxDbSize.
	 */
	public function getMaxDbSize() {
		return intval($this->maxDbSize);
	}
	
	
	
	

	/**
	 * Sets the notification email address.
	 *
	 * @param	string	$notificationEmail Notification email address.
	 */
	public function setNotificationEmail($notificationEmail) {
		$this->notificationEmail = $notificationEmail;
	}


	/**
	 * Sets the maxDbSize.
	 *
	 * @param	int	$maxDbSize 
	 */
	public function setMaxDbSize($maxDbSize) {
		$this->maxDbSize = intval($maxDbSize);
	}





	/**
	 * Sends a notification email, reporting system issues.
	 *
	 * @param	array	$systemStatus Array of statuses
	 */
	protected function sendNotificationEmail($groesse) {

		$subject = sprintf(
			$GLOBALS['LANG']->getLL('dbchecktask.email_subject'),
			$GLOBALS['TYPO3_CONF_VARS']['SYS']['sitename']
		);
		$subject.= ': '.$groesse;

		$message = sprintf(
			$GLOBALS['LANG']->getLL('dbchecktask.email_message'),
			'',
			''
		);
		$message.= CRLF . CRLF;

		$from =  $GLOBALS['TYPO3_CONF_VARS']['MAIL']['defaultMailFromAddress'];
        
        /** @var $mail \TYPO3\CMS\Core\Mail\MailMessage */
        $mail = GeneralUtility::makeInstance(\TYPO3\CMS\Core\Mail\MailMessage::class);
        $mail->setFrom($from)->setSubject($subject)->setBody($message);
		
		$arrAdr = explode(',', $this->notificationEmail);
		foreach($arrAdr as $adr){
            $mail->setTo($adr);
            $mail->send();
        }
	}


}

